# TextFlows Taggers Module #


A [TextFlows](https://github.com/xflows/textflows/) package, which contains python wrapper classes for four part-of-speech taggers, CRF tagger, TreeTagger, NLP4j and TNT. 


## Installation, documentation ##

Please find installation instructions, examples and API reference on [Read the Docs](http://docs.textflows.org/).

## Note ##

Please note that this is a research project and that drastic changes can be (and are) made pretty regularly. Changes are documented in the [CHANGELOG](CHANGELOG.md).

Pull requests and issues are welcome.

## Contributors to the tf_tagger package code ##

Matej Martinc (@matejMartinc)

* [Knowldge Technologies Department](http://kt.ijs.si), Jožef Stefan Institute, Ljubljana